from setuptools import setup

setup(
    name='boomerang-client',
    version='0.1',
    packages=['boomerang'],
    url='https://github.com/olalidmark/boomerang-client',
    license='MIT',
    author='fantomen',
    author_email='olalidmark@gmail.com',
    description='Boomerang.io Python API client',
    keywords=['boomerang', 'boomerang.io', 'api', 'rest'],
    classifiers=[
        'Development Status :: 4 - Beta',

        'Intended Audience :: Developers',

        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',

    ],
    install_requires=['requests'],
)



# -*- coding: utf-8 -*-
import urlparse
import requests

__author__ = 'ola'


class BoomerangClient:

    BASE_URL = 'http://api.boomerang.io/v1'

    def __init__(self, project_id, api_key):
        self.url = "%s/api_key/%s/projects/%s/boomerangs/" % (self.BASE_URL, api_key, project_id)

    def boomerang_url(self, bid):
        return urlparse.urljoin(self.url, bid)


    def get_all_boomerangs(self):
        res = requests.get(self.url)
        return res


    def get_one_boomerang(self, boomerang_id):
        res = requests.get(self.boomerang_url(boomerang_id))
        return res


    def create_boomerang(self, params):
        res = requests.post(self.url, params)
        return res


    def update_boomerang(self, boomerang_id):
        res = requests.put(self.boomerang_url(boomerang_id))
        return res


    def delete_boomerang(self, boomerang_id):
        res = requests.delete(self.boomerang_url(boomerang_id))
        return res
